@@ -69,6 +69,7 @@ def run_pokemon():
 	# no structure mapped 
 	if snps2aa_noidx.empty: 
 		outf.write('%s\tNA\tNA\n'%gene_name)
+		print("no structure mapped")
 		return None
 
 	snps2aa,pdb = filter_snps2aa(snps2aa_noidx, pdb=pdb)
@@ -83,6 +84,7 @@ def run_pokemon():
 	snps2aa_subset = snps2aa.merge(snps_sum.to_frame(),left_on='varcode',right_index=True)	
 	if snps2aa_subset['varcode'].nunique() < 5:
 		outf.write('%s\tNA\tNA\n'%gene_name)
+		print("# variance mapped  < 5")
 		return None
 
 	# get distance matrix
@@ -98,10 +100,12 @@ def run_pokemon():
 
 	if draw_figures: 
 		from lib.cluster import cluster
-		out_fig_prefix = figures_dir + '/' + gene_name + '_' + pdb
-		cls = cluster(genotype,snps2aa,phenotype,distance_mat,pdb)
-		cls.plot(out_fig_prefix)
-		cls.plot_cluster(out_fig_prefix)
+		for lab, ipheno in phenotype.iterrows():
+			out_fig_prefix = figures_dir + '/' + gene_name + '_' + lab  +'_' + pdb
+			ipheno = ipheno.to_frame(lab).T
+			cls = cluster(genotype,snps2aa,phenotype,distance_mat,pdb)
+			cls.plot(out_fig_prefix)
+			cls.plot_cluster(out_fig_prefix)
 
 	# calculate kernel based on the score matrix
 	K = cal_Kernel(combined_w, genotype)
